data<-matrix(scan("timed-gate24.bench"), ncol=4, byrow=TRUE)
fun<-data[,1]

# Analysis for afterDelay:

delayin<-data[fun==0,2]
delayout<-data[fun==0,3]
delaytime<-data[fun==0,4]
delayt<-data[fun==0,4]/1000000 # convert to milli seconds

# histogram of state set frequencies:
postscript(file="AfterDelayHist.eps", onefile=T) 
hist(delayin, breaks=40, xlab="State set size", main="Histogram of afterDelay inputs")

# Compute the averages (means) for each statesize:
delaymean<-tapply(delayt, delayin, mean) # means for each state size
delayind<-tapply(delayin, delayin, min) # index in case of windows in data

# Make analysis of variance and compute the coeficients for line:
delayobj<-aov(delayt~delayin) # analysis of variance
delaycoef<-coef(delayobj) # coeficients for line

# Plot the means:
postscript(file="AfterDelayMeans.eps", onefile=T) 
plot(delayind, delaymean, xlab="Initial state set size", ylab="Average afterDelay CPU time, milliseconds")

# Plot a line from linear model analysis:
abline(delaycoef)

# Plot all instances:
postscript(file="AfterDelayInst.eps", onefile=T) 
plot(delayt~delayin, xlab="Input state set size", ylab="Actual afterDelay CPU time, milliseconds")
abline(delaycoef)
# this would be better, but it gives logarithmic scale! :-(
#stripchart(delayt~delayin, xlab="Input state set size", ylab="Actual afterDelay CPU time, milliseconds", method="jitter", vertical=T, log="")

#================================================================
# Analysis for afterAction:

actionin<-data[fun==1,2]
actionout<-data[fun==1,3]
actiontime<-data[fun==1,4]
actiont<-data[fun==1,4]/1000000

# histogram of state set frequencies:
postscript(file="AfterActionHist.eps", onefile=T) 
hist(actionin, breaks=40, xlab="State set size", main="Histogram of afterAction input")

actionmean<-tapply(actiont, actionin, mean) # means
actionind<-tapply(actionin, actionin, min) # index

actionobj<-lm(actiont~actionin) # analysis of variance
actioncoef<-coef(actionobj) # coeficients for line

postscript(file="AfterActionMeans.eps", onefile=T) 
plot(actionind, actionmean, xlab="Input, state set size", ylab="Average afterAction CPU time, milliseconds") 
abline(actioncoef)

postscript(file="AfterActionInst.eps", onefile=T) 
plot(actiont~actionin, xlab="Input, state set size", ylab="Instances of afterAction CPU time, milliseconds")
abline(actioncoef)

quit()

# OTHER interresting things:

# 3D plot:

am<-tapply(actiont, list(actionin, actionout), mean)
aix<-tapply(actionin, actionin, min)
aox<-tapply(actionout, actionout, min)
persp(aix, aox, am)
